# Specification

## Overview

A checkable input that communicates if an option is true, false or indeterminate.

This specification is an extension of [SLDS Checkbox Specification](https://www.lightningdesignsystem.com/components/checkbox/) and [Lightning Web Component - Input Checkbox](https://developer.salesforce.com/docs/component-library/bundle/lightning-input/example).

### Anatomy and Appearance

#### DOM Structure

**Note:**
- Markup structure mirrors markup in the LBC template.
- The required asterisk and help text are dynamically generated.

```html
<div>
  <span part="input-checkbox">
    <abbr>*</abbr>
    <input type="checkbox" part="checkbox" />
    <label part="label-container">
      <span part="indicator"></span>
      <span part="label"></span>
    </label>
  </span>
  <div part="help-text"></div>
</div>
```

## API

### Parts

| Part Name         | Description                                  |
| ----------------- | -------------------------------------------- |
| `input-checkbox`  | Enables styling for component container      |
| `checkbox`        | Enables styling for the native input element |
| `label-container` | Enables styling for label container          |
| `label`           | Enables styling for label                    |
| `indicator`       | Enables styling for visual indicator         |
| `help-text`       | Enables styling for the help text            |

### Styling Hooks

| Property Name                                           | Fallback                         | Description                                       |
| ------------------------------------------------------- | -------------------------------- | ------------------------------------------------- |
| `--slds-c-inputcheckbox-label-spacing-inline-start`     | `--sds-g-spacing-2`              | Start spacing between label and indicator         |
| --                                                      | `--sds-g-color-error-base-50`    | Color of required indicator                       |
| --                                                      | `--sds-g-spacing-1`              | End spacing of required indicator                 |
| `--slds-c-inputcheckbox-sizing`                         | `1rem`                           | Width and height of indicator                     |
| `--slds-c-inputcheckbox-radius-border`                  | `--sds-g-radius-border-1`        | Border radius of indicator                        |
| `--slds-c-inputcheckbox-sizing-border`                  | `--sds-g-sizing-border-1`        | Border size of indicator                          |
| `--slds-c-inputcheckbox-sizing-border-invalid`          | `--sds-g-sizing-border-2`        | Border size of indicator invalid state            |
| `--slds-c-inputcheckbox-color-border`                   | `--sds-g-color-neutral-base-80`  | Border color of indicator                         |
| `--slds-c-inputcheckbox-color-border-checked`           |                                  | Border color of indicator checked state           |
| `--slds-c-inputcheckbox-color-border-disabled`          |                                  | Border color of indicator disabled state          |
| `--slds-c-inputcheckbox-color-border-focus`             | `--sds-g-color-brand-base-50`    | Border color of indicator focus state             |
| `--slds-c-inputcheckbox-color-border-invalid`           | `--sds-g-color-error-base-50`    | Border color of indicator invalid state           |
| `--slds-c-inputcheckbox-color-background`               | `--sds-g-color-neutral-base-100` | Background color of indicator                     |
| `--slds-c-inputcheckbox-color-background-checked`       |                                  | Background color of indicator checked state       |
| `--slds-c-inputcheckbox-color-background-disabled`      | `--sds-g-color-neutral-base-95`  | Background color of indicator disabled state      |
| `--slds-c-inputcheckbox-color-background-focus`         |                                  | Background color of indicator focus state         |
| `--slds-c-inputcheckbox-color-background-invalid`       |                                  | Background color of indicator invalid state       |
| `--slds-c-inputcheckbox-shadow`                         |                                  | Box shadow of indicator                           |
| `--slds-c-inputcheckbox-shadow-focus`                   | `--sds-g-color-brand-base-50`    | Box shadow of indicator focus state               |
| `--slds-c-inputcheckbox-mark-color-foreground`          | `--sds-g-color-brand-base-50`    | Foreground color of indicator mark                |
| `--slds-c-inputcheckbox-mark-color-foreground-disabled` | `--sds-g-color-neutral-base-60`  | Foreground color of indicator mark disabled state |
| `--slds-c-inputcheckbox-helptext-color-invalid`         | `--sds-g-color-error-base-50`    | Color of help text invalid state                  |
